{
    "$graph": [
        {
            "class": "Workflow",
            "doc": "Workflow to compare overlapping variants in two VCFs using GATK Concordance tool.\n",
            "id": "#main",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#main/reference",
                    "type": "File",
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ]
                },
                {
                    "id": "#main/eval",
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ]
                },
                {
                    "id": "#main/truth",
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ]
                },
                {
                    "id": "#main/summary",
                    "type": "string"
                }
            ],
            "steps": [
                {
                    "id": "#main/GATKConcordance",
                    "run": "#GATKConcordance.yaml.cwl",
                    "in": [
                        {
                            "id": "#main/GATKConcordance/reference",
                            "source": "#main/reference"
                        },
                        {
                            "id": "#main/GATKConcordance/eval",
                            "source": "#main/eval"
                        },
                        {
                            "id": "#main/GATKConcordance/truth",
                            "source": "#main/truth"
                        },
                        {
                            "id": "#main/GATKConcordance/summary",
                            "source": "#main/summary"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/GATKConcordance/concordance_summary"
                        }
                    ]
                }
            ],
            "outputs": [
                {
                    "id": "#main/concordance_summary",
                    "type": "File",
                    "outputSource": "#main/GATKConcordance/concordance_summary"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "doc": "GATK Concordance tool to compare overlapping variants in two VCFs.\n",
            "id": "#GATKConcordance.yaml.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "us.gcr.io/broad-gotc-prod/genomes-in-the-cloud:2.3.2-1510681135"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000
                }
            ],
            "baseCommand": [
                "/usr/gitc/gatk4/gatk-launch",
                "Concordance"
            ],
            "arguments": [
                {
                    "valueFrom": "-XX:GCHeapFreeLimit=10 -XX:+PrintFlagsFinal -XX:+PrintGCTimeStamps -XX:+PrintGCDateStamps -XX:+PrintGCDetails -Xloggc:gc_log.log -Xms4000m",
                    "position": 0,
                    "prefix": "--javaOptions",
                    "separate": true
                }
            ],
            "inputs": [
                {
                    "id": "#GATKConcordance.yaml.cwl/GATKConcordance/reference",
                    "type": "File",
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ],
                    "inputBinding": {
                        "prefix": "-R"
                    }
                },
                {
                    "id": "#GATKConcordance.yaml.cwl/GATKConcordance/eval",
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "inputBinding": {
                        "prefix": "-eval"
                    }
                },
                {
                    "id": "#GATKConcordance.yaml.cwl/GATKConcordance/truth",
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "inputBinding": {
                        "prefix": "--truth"
                    }
                },
                {
                    "id": "#GATKConcordance.yaml.cwl/GATKConcordance/summary",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--summary"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#GATKConcordance.yaml.cwl/GATKConcordance/concordance_summary",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.summary)"
                    }
                }
            ]
        }
    ],
    "cwlVersion": "v1.0"
}
